@@ -168,7 +168,7 @@ class TestMarkers:
             for ix, value in enumerate(temp_marker_list):
                 s.axes_manager.indices = (ix, iy)
                 vertical_line = s._plot.signal_plot.ax.lines[1]
-                assert value == vertical_line.get_data()[0]
+                assert value == vertical_line.get_data()[0][0]
 
     def test_add_marker_signal2d_navigation_dim(self):
         s = Signal2D(np.zeros((3, 50, 50)))
@@ -571,11 +571,11 @@ def test_plot_add_background_windows():
 def test_iterate_markers():
     from skimage.feature import peak_local_max
     try:
+        # scipy >=1.10
+        from scipy.datasets import face
+    except ImportError:
         # scipy <1.10
         from scipy.misc import face
-    except:
-        # scipy >=1.10
-        from scipy.dataset import face
     ims = BaseSignal(face()).as_signal2D([1, 2])
     index = np.array([peak_local_max(im.data, min_distance=100,
                                      num_peaks=4) for im in ims])
@@ -632,14 +632,14 @@ def test_plot_eds_markers_no_energy():
 @pytest.mark.mpl_image_compare(
     baseline_dir=baseline_dir, tolerance=default_tol, style=style_pytest_mpl)
 def test_plot_eels_labels():
-    s = get_core_loss_eels_line_scan_signal(True, random_state=10)
+    s = get_core_loss_eels_line_scan_signal(True, add_noise=False)
     s.add_elements(['Cr'])
     s.plot(plot_edges=True)
     return s._plot.signal_plot.figure
 
 
 def test_plot_eels_labels_nav():
-    s = get_core_loss_eels_line_scan_signal(True)
+    s = get_core_loss_eels_line_scan_signal(True, add_noise=False)
     s.add_elements(['Cr', 'Fe'])
     s.plot(plot_edges=True)
     s.axes_manager.indices = (10, )
